@@ -13,7 +13,7 @@ use Validation::Class::Util;
 
 use overload bool => \&validate, '""' => \&messages, fallback => 1;
 
-our $VERSION = '7.900049'; # VERSION
+our $VERSION = '7.900050'; # VERSION
 
 
 
@@ -157,6 +157,7 @@ sub AUTOLOAD {
 
 sub DESTROY {}
 
+
 1;
 
 __END__
@@ -169,7 +170,7 @@ Validation::Class::Simple::Streamer - Simple Streaming Data Validation
 
 =head1 VERSION
 
-version 7.900049
+version 7.900050
 
 =head1 SYNOPSIS
 
@@ -261,12 +262,219 @@ parameters.
 
 =head2 validate
 
-The validate method uses the validator to perform data validation based on
-the series and sequence of commands issued previously. This method is called
-implicitly whenever the object is used in boolean context, e.g. in a conditional.
+The validate method uses the validator to perform data validation based on the
+series and sequence of commands issued previously. This method is called
+implicitly whenever the object is used in boolean context, e.g. in a
+conditional.
 
     $true = $self->validate;
 
+=head1 PROXY METHODS
+
+Each instance of Validation::Class::Simple::Streamer is injected with a few
+proxy methods which are basically aliases to the corresponding prototype
+class methods, however it is possible to access the prototype directly using
+the proto/prototype methods.
+
+=head2 class
+
+    $self->class;
+
+See L<Validation::Class::Prototype/class> for full documentation.
+
+=head2 clear_queue
+
+    $self->clear_queue;
+
+See L<Validation::Class::Prototype/clear_queue> for full documentation.
+
+=head2 error_count
+
+    $self->error_count;
+
+See L<Validation::Class::Prototype/error_count> for full documentation.
+
+=head2 error_fields
+
+    $self->error_fields;
+
+See L<Validation::Class::Prototype/error_fields> for full documentation.
+
+=head2 errors
+
+    $self->errors;
+
+See L<Validation::Class::Prototype/errors> for full documentation.
+
+=head2 errors_to_string
+
+    $self->errors_to_string;
+
+See L<Validation::Class::Prototype/errors_to_string> for full documentation.
+
+=head2 get_errors
+
+    $self->get_errors;
+
+See L<Validation::Class::Prototype/get_errors> for full documentation.
+
+=head2 get_fields
+
+    $self->get_fields;
+
+See L<Validation::Class::Prototype/get_fields> for full documentation.
+
+=head2 get_hash
+
+    $self->get_hash;
+
+See L<Validation::Class::Prototype/get_hash> for full documentation.
+
+=head2 get_params
+
+    $self->get_params;
+
+See L<Validation::Class::Prototype/get_params> for full documentation.
+
+=head2 get_values
+
+    $self->get_values;
+
+See L<Validation::Class::Prototype/get_values> for full documentation.
+
+=head2 fields
+
+    $self->fields;
+
+See L<Validation::Class::Prototype/fields> for full documentation.
+
+=head2 filtering
+
+    $self->filtering;
+
+See L<Validation::Class::Prototype/filtering> for full documentation.
+
+=head2 ignore_failure
+
+    $self->ignore_failure;
+
+See L<Validation::Class::Prototype/ignore_failure> for full documentation.
+
+=head2 ignore_unknown
+
+    $self->ignore_unknown;
+
+See L<Validation::Class::Prototype/ignore_unknown> for full documentation.
+
+=head2 is_valid
+
+    $self->is_valid;
+
+See L<Validation::Class::Prototype/is_valid> for full documentation.
+
+=head2 param
+
+    $self->param;
+
+See L<Validation::Class::Prototype/param> for full documentation.
+
+=head2 params
+
+    $self->params;
+
+See L<Validation::Class::Prototype/params> for full documentation.
+
+=head2 plugin
+
+    $self->plugin;
+
+See L<Validation::Class::Prototype/plugin> for full documentation.
+
+=head2 queue
+
+    $self->queue;
+
+See L<Validation::Class::Prototype/queue> for full documentation.
+
+=head2 report_failure
+
+    $self->report_failure;
+
+See L<Validation::Class::Prototype/report_failure> for full
+documentation.
+
+=head2 report_unknown
+
+    $self->report_unknown;
+
+See L<Validation::Class::Prototype/report_unknown> for full documentation.
+
+=head2 reset_errors
+
+    $self->reset_errors;
+
+See L<Validation::Class::Prototype/reset_errors> for full documentation.
+
+=head2 reset_fields
+
+    $self->reset_fields;
+
+See L<Validation::Class::Prototype/reset_fields> for full documentation.
+
+=head2 reset_params
+
+    $self->reset_params;
+
+See L<Validation::Class::Prototype/reset_params> for full documentation.
+
+=head2 set_errors
+
+    $self->set_errors;
+
+See L<Validation::Class::Prototype/set_errors> for full documentation.
+
+=head2 set_fields
+
+    $self->set_fields;
+
+See L<Validation::Class::Prototype/set_fields> for full documentation.
+
+=head2 set_params
+
+    $self->set_params;
+
+See L<Validation::Class::Prototype/set_params> for full documentation.
+
+=head2 set_method
+
+    $self->set_method;
+
+See L<Validation::Class::Prototype/set_method> for full documentation.
+
+=head2 stash
+
+    $self->stash;
+
+See L<Validation::Class::Prototype/stash> for full documentation.
+
+=head2 validate
+
+    $self->validate;
+
+See L<Validation::Class::Prototype/validate> for full documentation.
+
+=head2 validate_method
+
+    $self->validate_method;
+
+See L<Validation::Class::Prototype/validate_method> for full documentation.
+
+=head2 validate_profile
+
+    $self->validate_profile;
+
+See L<Validation::Class::Prototype/validate_profile> for full documentation.
+
 =head1 AUTHOR
 
 Al Newkirk <anewkirk@ana.io>
